@@ -30,7 +30,7 @@ This is list of methods in this package.
 =cut
 
 use vars qw/$VERSION %Grammars @GrammarOrder %Commands/;
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 @GrammarOrder = qw(
   take_from add_dry put fold add remove combine divide
@@ -85,8 +85,8 @@ $VERSION = '1.00';
         my $recipe = shift;
         local $_ = shift;
         my $regex;
-        if (/ into (?:the )?(?:$ord )?mixing bowl$/) {
-           $regex = qr/^Add (?:the )?$ingr into (?:the )?(?:$ord )?mixing bowl$/;
+        if (/ to (?:the )?(?:$ord )?mixing bowl$/) {
+           $regex = qr/^Add (?:the )?$ingr to (?:the )?(?:$ord )?mixing bowl$/;
         } else {
            $regex = qr/^Add (?:the )?$ingr()$/;
         }
@@ -144,7 +144,7 @@ $VERSION = '1.00';
      add_dry => sub {
         my $recipe = shift;
         local $_ = shift;
-        /^Add (?:the )?dry ingredients(?: into (?:the )?(?:$ord )?mixing bowl)?$/ or return();
+        /^Add (?:the )?dry ingredients(?: to (?:the )?(?:$ord )?mixing bowl)?$/ or return();
         $recipe->require_bowl($1||1);
         return 'add_dry', ($1||1);
      },
@@ -152,7 +152,7 @@ $VERSION = '1.00';
      liquify_contents => sub {
         my $recipe = shift;
         local $_ = shift;
-        /^Liquify (?:the )?contents of (?:the )?(?:$ord )?mixing bowl$/ or return();
+        /^Liqu(?:i|e)fy (?:the )?contents of (?:the )?(?:$ord )?mixing bowl$/ or return();
         $recipe->require_bowl($1||1);
         return 'liquify_contents', ($1||1);
      },
@@ -160,7 +160,7 @@ $VERSION = '1.00';
      liquify => sub {
         my $recipe = shift;
         local $_ = shift;
-        /^Liquify (?:the )?$ingr$/ or return();
+        /^Liqu(?:i|e)fy (?:the )?$ingr$/ or return();
         $recipe->require_ingredient($1, 'liquify');
         return 'liquify', $1;
      },
